@@ -454,6 +454,8 @@ exp_lao(struct pat *top, enum ptype lao) {
 
 private struct pat *
 exp_exp(struct pat *top) {
+	if (top == NULL)
+		warn_exit("illegal pattern.\n");
 	top = exp_sq(top);
 	top = exp_not(top);
 	top = exp_lao(top, P_AND);
@@ -639,7 +641,7 @@ main(int argc, char *argv[])
 #endif /* DEBUG */
 
 /* 
- * Copyright (C) 2000-2001 Mew developing team.
+ * Copyright (C) 2000-2002 Mew developing team.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
