@@ -511,8 +511,12 @@
 	(forward-line)
 	(setq limit1 (1+ (point)))))))
 
-(defun mew-header-encode-region (beg end)
-  (let (key med type str start last)
+(defun mew-header-resent-p (field)
+  (let ((case-fold-search t))
+    (string-match mew-resent-regex field)))
+
+(defun mew-header-encode-region (beg end &optional resentp)
+  (let (key med type str start last fast-path)
     (save-restriction
       (narrow-to-region beg end)
       (mew-header-sanity-check-region (point-min) (point-max))
@@ -525,13 +529,19 @@
 	  (setq key (mew-match 1))
 	  (setq med (match-end 0))
 	  (setq type (mew-field-type-for-encoding key))
+	  (setq fast-path t)
+	  (if (eq type 'mailbox)
+	      (if resentp
+		  (if (mew-header-resent-p key)
+		      (setq fast-path nil))
+		(if (not (mew-header-resent-p key))
+		    (setq fast-path nil))))
 	  (forward-line)
 	  (mew-header-goto-next)
 	  (setq last (1- (point)))
-	  (if (= last med)
-	      ()
+	  (unless (= last med)
 	    (if (and (string= (mew-charset-guess-region med last) mew-us-ascii)
-		     (not (eq type 'mailbox)))
+		     fast-path)
 		() ;; fast path
 	      ;; if us-ascii AND mailbox, need to check syntax
 	      (setq str (mew-buffer-substring med (1- (point))))
@@ -644,7 +654,7 @@
 	(concat "The '" param "' parameter has encoded-word.\n")))
       (mew-xinfo-get-warning)))))
 
-(defun mew-header-decode-region (key rbeg rend)
+(defun mew-header-decode-region (key rbeg rend &optional draftp)
   "RFC 2047 decoding. This is liberal on the one point from RFC 2047.
 That is, each line may be more than 75. "
   (setq key (capitalize key))
@@ -653,10 +663,12 @@ That is, each line may be more than 75. "
       (narrow-to-region rbeg rend)
       ;; Handling illegal raw text.
       (goto-char (point-min))
-      (when (and mew-decode-broken
-		 (re-search-forward mew-regex-esc-or-nonascii nil t))
-	(mew-decode-warning-fields key 'raw)
-	(mew-cs-decode-region (point-min) (point-max) mew-cs-autoconv))
+      (if draftp
+	  (mew-cs-decode-region (point-min) (point-max) mew-cs-m17n)
+	(when (and mew-decode-broken
+		   (re-search-forward mew-regex-esc-or-nonascii nil t))
+	  (mew-decode-warning-fields key 'raw)
+	  (mew-cs-decode-region (point-min) (point-max) mew-cs-autoconv)))
       ;;
       (mew-header-unfold-region type)
       ;;
@@ -867,7 +879,8 @@ That is, each line may be more than 75. "
 
 (defun mew-param-analyze-broken (value name)
   ;; broken message handling
-  (when (string-match mew-regex-esc-or-nonascii value)
+  (when (and (mew-member-case-equal name mew-broken-parameter-list)
+	     (string-match mew-regex-esc-or-nonascii value))
     (mew-decode-warning-params name 'raw)
     (setq value (mew-cs-decode-string value mew-cs-autoconv)))
   (when (string-match mew-header-decode-regex value)
@@ -897,7 +910,7 @@ That is, each line may be more than 75. "
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2001 Mew developing team.
+;; Copyright (C) 1997-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
