@@ -374,7 +374,7 @@ the name exists."
       (mew-complete-insert WORD)
       ;;(mew-complete-window-delete)
       (if (window-minibuffer-p (get-buffer-window (current-buffer)))
-	  (mew-temp-minibuffer-message (concat " No matching " MSG))
+	  (mew-temp-minibuffer-message (format " [No matching %s]" MSG))
 	(message "No matching %s" MSG))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -422,7 +422,9 @@ the name exists."
       (forward-char 1)
     (beginning-of-line))
   (prog1
-      (cons (mew-buffer-substring (point-min) (point))
+      (cons (mew-buffer-substring (save-excursion (beginning-of-line)
+						  (point))
+				  (point))
 	    (mew-buffer-substring (point) (point-max)))
     (delete-region (point) (point-max))))
 
@@ -491,7 +493,7 @@ the name exists."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2001 Mew developing team.
+;; Copyright (C) 1997-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
