@@ -2,7 +2,6 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Feb  1, 1999
-;; Revised: Jul  8, 2001
 
 ;;; Code:
 
@@ -43,6 +42,8 @@
 (defconst mew-resent-dcc:  "Resent-Dcc:")
 (defconst mew-resent-fcc:  "Resent-Fcc:")
 
+(defconst mew-resent-regex "^Resent-")
+
 (defconst mew-resent-message-id: "Resent-Message-Id:")
 
 (defconst mew-reply-to:     "Reply-To:")
@@ -60,10 +61,10 @@
 
 (defconst mew-received: "Received:")
 
-(defconst mew-x-mailer:   "X-Mailer:")
-(defconst mew-x-face:     "X-Face:")
-(defconst mew-x-mew:      "X-Mew:")
-(defconst mew-x-mew-uidl: "X-Mew-UIDL:")
+(defconst mew-x-mailer:    "X-Mailer:")
+(defconst mew-x-face:      "X-Face:")
+(defconst mew-x-mew:       "X-Mew:")
+(defconst mew-x-mew-uidl:  "X-Mew-Uidl:")
 
 (defconst mew-keywords: "Keywords:")
 (defconst mew-body:	"Body:")
@@ -79,6 +80,7 @@
 
 (defconst mew-ct-txt "Text/Plain")
 (defconst mew-ct-htm "Text/Html")
+(defconst mew-ct-xml "Text/Xml")
 (defconst mew-ct-msg "Message/Rfc822")
 (defconst mew-ct-ext "Message/External-Body")
 (defconst mew-ct-sts "Message/Delivery-Status")
@@ -89,6 +91,7 @@
 (defconst mew-ct-mld "Multipart/Digest")
 (defconst mew-ct-ado "Audio/Basic")
 (defconst mew-ct-apo "Application/Octet-Stream")
+(defconst mew-ct-aps "Application/Postscript")
 (defconst mew-ct-apk "Application/Pgp-Keys")
 (defconst mew-ct-pgs "application/pgp-signature") ;; due to the RFC 1847 bug
 (defconst mew-ct-pge "application/pgp-encrypted") ;; due to the RFC 1847 bug
@@ -200,7 +203,7 @@
 (defconst mew-regex-virtual-thread
   "[^\r\n]+\r\\( \\([-+%=/~][^ ]*\\) \\([0-9]+\\)\\)? <\\([^>]*\\)> <\\([^>]*\\)>$")
 
-;; [\033\200-\377] doesn't work due to the multibyte
+;; [\033\200-\377] does not work due to the multibyte
 (defconst mew-regex-esc-or-nonascii "[^\000-\032\034-\177]") ;; \033 = esc
 (defconst mew-regex-nonascii "[^\000-\177]")
 
@@ -213,7 +216,7 @@
 ;; Can skip \n. Match the first id. For example:
 ;; In-Reply-To: Your message of "Mon, 5 Oct 1998 13:33:14 +0900"
 ;; 	<19981005133317N.kazu@iijlab.net>
-(defconst mew-regex-id "<\\([^>]+\\)>")
+(defconst mew-regex-id "<\\([^>\n\t]+\\)>")
 
 (defsubst mew-regex-jmp-msg (msg)
   (concat  "^[ ]*" msg "[^0-9]"))
@@ -228,14 +231,14 @@
 (defconst mew-case-default "default"
   "The default value for case.")
 
-(defconst mew-draft-coverpage "CoverPage")
+(defconst mew-draft-coverpage "Cover.txt")
 
 
 (provide 'mew-const)
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 2000-2001 Mew developing team.
+;; Copyright (C) 2000-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
