@@ -697,7 +697,8 @@ Does not examine containing directories for links."
     (mew-make-directory mew-temp-dir)) ;; just in case
   (if fname
       ;; File name of a temporary file should be ASCII only.
-      (if (string-match "^[ -~]+$" fname)
+      (if (and (string-match "^[ -~]+$" fname)
+	       (not (file-exists-p (expand-file-name fname mew-temp-dir))))
 	  (expand-file-name fname mew-temp-dir)	
 	(if (string-match "\\.[ -~]+$" fname)
 	    (concat (make-temp-name mew-temp-file) (mew-match 0 fname))
