@@ -2,7 +2,6 @@
 
 ;; Author:  Kazu Yamamoto <Kazu@Mew.org>
 ;; Created: Jun 22, 2000
-;; Revised: Jul  8, 2001
 
 ;;; Code:
 
@@ -102,10 +101,10 @@
 ;;;
 
 (defun mew-image-inline-p (format)
-  (image-type-available-p format))
+  (and window-system (image-type-available-p format)))
 
 (defun mew-mime-image (cache begin end format)
-  (message "Loading image ... ")
+  (message "Loading image...")
   (set-buffer (mew-buffer-message))
   (mew-elet
    (condition-case nil
@@ -117,7 +116,7 @@
 		      nil t))
      (error ())))
   (goto-char (point-min))
-  (message "Loading image ... done"))
+  (message "Loading image...done"))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;;
@@ -139,7 +138,7 @@
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2001 Mew developing team.
+;; Copyright (C) 1997-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
