@@ -302,7 +302,7 @@
 
 (unless mew-draft-mode-map
   (setq mew-draft-mode-map (make-sparse-keymap))
-  (set-keymap-parent mew-draft-mode-map mew-draft-body-map))
+  (mew-set-keymap-parent mew-draft-mode-map mew-draft-body-map))
 
 (defvar mew-draft-mode-toolbar-menu
   '("Attachment Commands"
