@@ -169,10 +169,26 @@ at completions."
 
 (defvar mew-input-sort-key-hist nil)
 
+(defun mew-sort-key-check ()
+  (let* ((field:mode (mew-buffer-substring 
+		      (save-excursion (beginning-of-line) (point))
+		      (point-max)))
+	 (mode (car (cdr (mew-split field:mode ?:))))
+	 err)
+    (if mode
+	(unless (member mode mew-sort-modes)
+	  (setq err mode)))
+    (if err
+        (progn
+          (mew-temp-minibuffer-message (format " [No match: %s]" err))
+          nil)
+      t)))
+
 (defun mew-input-sort-key (key)
   (mew-input-clear)
   (setq mew-input-complete-function (function mew-complete-sort-key))
-  (let* ((field:mode (read-from-minibuffer
+  (let* ((mew-exit-minibuffer-function (function mew-sort-key-check))
+	 (field:mode (read-from-minibuffer
 		      (format "Sort by (%s)? : " key)
 		      ""
 		      mew-input-map
@@ -290,7 +306,7 @@ at completions."
       (setq file mew-home))
      ((or (string-match (format "^[~%s]" mew-path-separator) default)
         ;; allow drive letter -- "^\\([A-Za-z]:\\|[~%s]\\)"
-        (string-match (format "^[A-Za-z]:%s.+" mew-path-separator) default))
+        (string-match (format "^[A-Za-z]:%s" mew-path-separator) default))
       (setq file default))
      (t
       (setq file (concat mew-home default))))
@@ -545,7 +561,7 @@ at completions."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1997-2001 Mew developing team.
+;; Copyright (C) 1997-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
