@@ -142,7 +142,7 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
   '("DUMMY"
     "^WARNING:[ -9;-~\n]+belongs? to:"
     "^WARNING:[ -9;-~\n]+belongs? to:"
-    "no info to calculate a trust probability")) ;;xxx
+    "There is no indication that this key really belongs to the owner"))
 
 (defconst mew-pgp-msg-no-vrfkey
   '("Key matching" "unknown keyid" "key does not meet" "public key not found"))
@@ -412,14 +412,14 @@ Set 1 if 5. Set 2 if 6. Set 3 if GNUPG.")
 (defun mew-pgp-encrypt-check ()
   (let (ret) ;; this should be nil
     (goto-char (point-min))
-    (if (search-forward (mew-pgp-get mew-pgp-msg-no-enckey) nil t)
-	(setq ret mew-pgp-result-pubkey)
+    (if (re-search-forward (mew-pgp-get mew-pgp-msg-no-validkey) nil t)
+        (setq ret mew-pgp-result-invalid)
       (goto-char (point-min))
-      (if (search-forward (mew-pgp-get mew-pgp-msg-no-keyring) nil t)
-	  (setq ret mew-pgp-result-pubring)
-	(goto-char (point-min))
-	(if (re-search-forward (mew-pgp-get mew-pgp-msg-no-validkey) nil t)
-	    (setq ret mew-pgp-result-invalid))))
+      (if (search-forward (mew-pgp-get mew-pgp-msg-no-enckey) nil t)
+          (setq ret mew-pgp-result-pubkey)
+        (goto-char (point-min))
+        (if (search-forward (mew-pgp-get mew-pgp-msg-no-keyring) nil t)
+            (setq ret mew-pgp-result-pubring))))
     ret))
 
 (defun mew-pgp-encrypt (file1 decrypters)
