@@ -97,8 +97,8 @@
     (setq mew-smime-string nil)
     (setq mew-smime-running 'signing)
     (let ((process-connection-type mew-connection-type2)
-	  file2 process)
-      (setq file2 (mew-make-temp-name mew-smime-signature-filename))
+	  (file2 (mew-make-temp-name))
+	  process)
       ;; not perfectly unique but OK
       (setq process
 	    (mew-start-process-lang
@@ -114,9 +114,8 @@
       (mew-rendezvous mew-smime-running)
       (message "S/MIME signing...done")
       (list file2 mew-b64 "sha1" mew-smime-sign-error
-	    (list "application/x-pkcs7-signature")
-	    (list "attachment" (list "filename" mew-smime-signature-filename))
-	    )))) ;; return
+            (list "application/x-pkcs7-signature")
+	    mew-smime-signature-filename))))
 
 (defun mew-smime-verify (file1 file2)
   (message "S/MIME verifying...")
