@@ -68,6 +68,7 @@
 
 (defvar mew-port-db
   '(("pop3" . "110")
+    ("nntp" . "119")
     ("smtp" . "25")))
 
 (defun mew-serv-to-port (serv)
@@ -154,6 +155,7 @@ after '/'. "
   (when (mew-debug 'net)
     (save-excursion
       (set-buffer (get-buffer-create mew-buffer-debug))
+      (goto-char (point-max))
       (insert (format "\n<%s>\n%s\n" label string)))))
 
 (defun mew-ssh-filter (process string)
@@ -222,7 +224,7 @@ after '/'. "
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2001 Mew developing team.
+;; Copyright (C) 1999-2002 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
