@@ -156,13 +156,14 @@
 (defsubst mew-syntax-cat (syntax part)
   (vconcat syntax (vector part)))
 
-(defun mew-syntax-cdp-format (ct file)
+(defun mew-syntax-cdp-format (ct file &optional cdp)
   (let* ((cdpdb (mew-cdpdb-by-ct ct))
 	 (val (mew-cdpdb-val cdpdb))
 	 (filep (mew-cdpdb-file cdpdb)))
+    (if (stringp cdp) (setq file cdp))
     (when val
       (if (and filep file)
-	  (list val (list "filename" (mew-header-sanity-check-string file)))
+	  (list val (list "filename" (file-name-nondirectory (mew-header-sanity-check-string file))))
 	(list val)))))
 
 ;; Encryption
@@ -190,7 +191,8 @@
 	;; nums sould be "1"
 	body)))
    ((mew-syntax-multipart-p syntax)
-    (if (null nums) syntax
+    (if (null nums)
+	syntax
       (mew-syntax-get-entry
        (aref syntax (+ mew-syntax-magic (1- (car nums)))) (cdr nums))))))
 
@@ -386,7 +388,8 @@
 (defun mew-encode-syntax-single (file &optional ctl cte cd cid cdp 
 				      privacy decrypters)
   ;; cid is just for beauty
-  ;; if cdp is *non-nil*, set cdp from file.
+  ;; if cdp is t, set cdp from file.
+  ;; if cdp is a string, set cdp from cdp.
   (let* (ct ctdb)
     (cond
      (ctl
@@ -400,12 +403,12 @@
 	(setq ctdb (mew-ctdb-by-ct ct)))
       (setq ctl (list ct))))
     (or cte (setq cte (mew-ctdb-cte ctdb)))
-    (if cdp (setq cdp (mew-syntax-cdp-format ct file)))
+    (if cdp (setq cdp (mew-syntax-cdp-format ct file cdp)))
     (vconcat [single] (list file decrypters privacy ctl cte cd cid cdp))))
 
 (defun mew-encode-syntax-multi (dir ct)
-  (if (not (string-match (concat mew-path-separator "$") dir))
-      (setq dir (file-name-as-directory dir)))
+  (unless (string-match (concat mew-path-separator "$") dir)
+    (setq dir (file-name-as-directory dir)))
   (vconcat [multi] (list dir) [nil nil] (list ct) [nil nil nil nil]))
 
 (defun mew-encode-syntax-text ()
@@ -440,7 +443,7 @@
 
 (defun mew-decode-syntax-rfc822 (&optional msg-head)
   ;; msg-head may include CD:
-  (if (null msg-head) (setq msg-head (mew-decode-syntax-rfc822-head t)))
+  (unless msg-head (setq msg-head (mew-decode-syntax-rfc822-head t)))
   (vconcat msg-head (vector (mew-decode-syntax-text))))
 
 (defun mew-decode-syntax-rfc822-head (&optional reg-hend)
@@ -700,13 +703,14 @@
       (while (< i N)
 	(setq ctm (nth 0 (nth i privacy)))
 	(setq ctp (nth 1 (nth i privacy)))
-	(cond
-	 ((mew-case-equal "pgp"  ctp) (aset marks (* i 2) ?P))
-	 ((mew-case-equal "moss" ctp) (aset marks (* i 2) ?M)))
-	(cond
-	 ((mew-case-equal mew-ct-mle ctm) (aset marks (1+ (* i 2)) ?E))
-	 ((mew-case-equal mew-ct-mls ctm) (aset marks (1+ (* i 2)) ?S)))
-	(setq i (1+ i))))
+	(let ((case-fold-search t))
+	  (cond
+	   ((string-match "pgp"  ctp) (aset marks (* i 2) ?P))
+	   ((string-match "moss" ctp) (aset marks (* i 2) ?M)))
+	  (cond
+	   ((mew-case-equal mew-ct-mle ctm) (aset marks (1+ (* i 2)) ?E))
+	   ((mew-case-equal mew-ct-mls ctm) (aset marks (1+ (* i 2)) ?S)))
+	  (setq i (1+ i)))))
 
     (if (and (not dec) decrypters) (setq cd-or-dec decrypters))
     (setq cd-or-dec (mew-substring cd-or-dec ld 'cnt))
@@ -944,7 +948,7 @@
   (mew-elet
    (let (beg)
      (goto-char (point-max))
-     (if (null (bolp)) (insert "\n"))
+     (unless (bolp) (insert "\n"))
      (setq beg (point))
      (insert "\n")
      (insert mew-draft-attach-boundary-beg)
